/**
* Monoxide-Doop plugin for mfdc-repl
*
* Attempt to load a Monoxide environment from a database name
* This looks at the first parameter passed to the main repl program and uses that to connect
*
* @author Matt Carter <m@ttcarter.com>
* @date 2016-12-08
*/

var _ = require('lodash');
var async = require('async-chainable');
var colors = require('chalk');
var monoxide = require('monoxide');

module.exports = function(finish, app) {
	async()
		.then(function(next) {
			if (!app.args.length) return next('No arguments passed');
			next();
		})
		.then(function(next) {
			if (app.verbose >= 1) console.log(colors.blue('[Monoxide-CLI]'), 'attempting to connect to', colors.cyan(app.args[0]));

			monoxide.connect('mongodb://localhost/' + app.args[0], next)
				.on('error', err => next(err))
		})
		.then(function(next) {
			app.repl.globals.db = monoxide.models;
			app.repl.globals.o = app.repl.globals.monoxide = monoxide;

			monoxide.connection.db.listCollections()
				.toArray()
				.then(models => models.forEach(model => {
					console.log('LD', model.name);
					monoxide.models[model.name] = monoxide.monoxideModel({
						$collection: model.name,
					});
					console.log('DONELD', model.name);
				}));

			next();
		})
		.end(finish);
};
